..
  class.rst

ardt.preprocessors.NotchFilter
==============================

.. currentmodule:: ardt.preprocessors

.. autoclass:: NotchFilter
    :members:
    :show-inheritance:
    :inherited-members:
